@@ -15,7 +15,7 @@ ssl._create_default_https_context = ssl._create_unverified_context
 from termcolor import cprint
 from inspect import currentframe
 
-__version__ = '0.1.47'
+__version__ = '0.1.48'
 
 __info__ = {
     '2022/01/04: 0.1.18 加入 __info__。',
@@ -41,7 +41,8 @@ __info__ = {
     '2022/08/12: 0.1.41 Remove password and 加入 finmind',
     '2022/08/12: 0.1.42 fix redis 跳出問題',
     '2022/08/18: 0.1.43 修改 redis_msg_sender(), 增加 channel參數',
-    '2022/08/19: 0.1.44 修改Tredis，改成兩個thread，避免任何block'
+    '2022/08/19: 0.1.44 修改Tredis，改成兩個thread，避免任何block',
+    '2022/08/30: 0.1.48 修改 get_all_stock_code_name_dict() 加入account'
 }
 
 
@@ -111,7 +112,7 @@ def __LINE__():
     return cf.f_back.f_lineno
 
 
-def get_all_stock_code_name_dict():
+def get_all_stock_code_name_dict(id='PAPIUSER08', password='2222'):
     today = datetime.datetime.today()
 
     cache_file = f'all_stock_code-{today.strftime("%Y%m%d")}.json'
@@ -120,9 +121,9 @@ def get_all_stock_code_name_dict():
 
         import shioaji as sj
 
-        def simu_login(id='PAPIUSER08', password='2222'):
+        def simu_login(id=id, password=password):
             print(f'使用測試帳號 {id} {password}')
-            api = sj.Shioaji(simulation=True)
+            api = sj.Shioaji()
             api.login(id, password, contracts_cb=lambda security_type: print(f"{repr(security_type)} fetch done."))
             return api
 
@@ -139,10 +140,12 @@ def get_all_stock_code_name_dict():
 
         with open(cache_file, 'w') as fp:
             json.dump(all_code_name_dir, fp)
+        api.logout()
     else:
         with open(cache_file, 'r') as fp:
             all_code_name_dir = json.load(fp)
 
+
     return all_code_name_dir
 
 
@@ -794,14 +797,14 @@ def get_trade_days(date_start: Union[str, datetime.datetime] = '2018-01-01',
 if __name__ == '__main__':
     from time import sleep
 
+    print(get_all_stock_code_name_dict('H121933940', '123edcxzaqws'))
+
     if True:
         ret = get_trade_days()
         print(ret)
 
         exit(0)
 
-
-
     if False:
         build_dealer_downloader()
 
